.. -*- coding: utf-8 -*-

=================================
``pybill.lib.pdfwriters`` package
=================================

.. automodule:: pybill.lib.pdfwriters

``writers`` module
==================

.. automodule:: pybill.lib.pdfwriters.writers

``utils`` module
================

.. automodule:: pybill.lib.pdfwriters.utils

``flowgenerators`` sub-package
==============================

.. automodule:: pybill.lib.pdfwriters.flowgenerators

``templates`` sub-package
=========================

.. automodule:: pybill.lib.pdfwriters.templates
